# Pygments lexer for Ursa programming language

Reuben Thomas <rrt@sc3d.org>  

This is a lexer for the [Ursa programming language](https://ursalang.github.io)
for use with the syntax highlighter [Pygments](https://pygments.org).

It is distributed under a BSD license.

I hope it will one day be part of the Pygments distribution.


## Installation

The easiest way to install is from PyPI, the Python Package Index:

`pip install pygments-lexer-ursa`

This will install Pygments itself if you don’t already have it installed.


## Usage

To run Pygments on an Ursa file:

`pygmentize FILE.ursa`

